# SurveyGen: Naming Scheme

## Mikro-Level Naming Scheme (Q&A Level)

- Question Stem (Questions related to a specific category e.g. "What is your opinion of ...") -> question_stem
- Question Content (e.g. _Is talkative_ in "Do you think this statement fits to you is talkative") -> question_content
- Question = Question Stem + Question Content (doesn't have to be composite, can be single question) -> question
- Answer Code (1: ..., 2: ..., can also be characters) -> answer_code
- Answer Text (e.g. "Agree", "Disagree", ...) -> answer_text
    - randomized
    - reversed
    - odd vs. even scaling
    - Refusal (non-substantive responses like "Don't know", etc.)
- Answer option = Answer Code + Answer Text -> answer_option
- Survey Item ID (im01, im02, (identifier for item)) -> survey_item_id
- Survey Item = Question + Answer Option -> survey_item
- LLM Response -> llm_response

**Scale Types**

- Nominal Scale:
    - Single-Choice (e.g. marital status)
    - Multiple-Choice (e.g. spoken languages)
- Ordinal Scale:
    - Likert Scales (e.g. agreement)
    - semantic differential scales (bipolar adjectives at scale ends, e.g. expensive <-> affordable)
- Interval Scales
    - numeric/linear scales (often from 1 to 10)
- Ratio Scales
    - interval scales with an absolute zero (working hours per week)


## Macro-Level Naming Scheme (Survey Level)

- Constructs (multiple items build one construct)
